@@ -5,13 +5,8 @@
 ;;; key sizes is supported.
 
 (in-package :crypto)
+(in-ironclad-readtable)
 
-#+(and sbcl x86-64)
-(eval-when (:compile-toplevel :load-toplevel :execute)
-  (defun aes-ni-support-p ()
-    (aes-ni-support-p))
-  (when (aes-ni-support-p)
-    (pushnew :aes-ni *features*)))
 
 ;;; FIXME: is it work it to combine these into one large array and
 ;;; subscript into that rather than having separate arrays?  CMUCL
@@ -714,7 +709,7 @@
     (declare (type (integer 0 43) round-key-offset))
     (macrolet ((rk-ref (x) `(aref round-keys (+ ,x round-key-offset))))
       (dotimes (i 4)
-        (setf (rk-ref i) (nibbles:ub32ref/be key (* 4 i))))
+        (setf (rk-ref i) (ub32ref/be key (* 4 i))))
       (dotimes (i 10 (values round-keys 10))
         (declare (type (integer 0 10) i))
         (let ((tmp (rk-ref 3)))
@@ -739,7 +734,7 @@
     (declare (type (integer 0 51) round-key-offset))
     (macrolet ((rk-ref (x) `(aref round-keys (+ ,x round-key-offset))))
       (dotimes (i 6)
-        (setf (rk-ref i) (nibbles:ub32ref/be key (* 4 i))))
+        (setf (rk-ref i) (ub32ref/be key (* 4 i))))
       (dotimes (i 8)
         (let ((tmp (rk-ref 5)))
           (declare (type (unsigned-byte 32) tmp))
@@ -767,7 +762,7 @@
     (declare (type (integer 0 59) round-key-offset))
     (macrolet ((rk-ref (x) `(aref round-keys (+ ,x round-key-offset))))
       (dotimes (i 8)
-        (setf (rk-ref i) (nibbles:ub32ref/be key (* 4 i))))
+        (setf (rk-ref i) (ub32ref/be key (* 4 i))))
       (dotimes (i 7)
         (let ((tmp (rk-ref 7)))
           (declare (type (unsigned-byte 32) tmp))
