@@ -2,6 +2,7 @@
 ;;;; crc32.lisp
 
 (in-package :crypto)
+(in-ironclad-readtable)
 
 (declaim (type (simple-array (unsigned-byte 32) (256)) +crc32-table+))
 (defconst +crc32-table+
@@ -85,15 +86,10 @@
   (flet ((stuff-state (crc digest start)
            (declare (type (simple-array (unsigned-byte 8) (*)) digest))
            (declare (type (integer 0 #.(- array-dimension-limit 4)) start))
-           (setf (nibbles:ub32ref/be digest start) crc)
+           (setf (ub32ref/be digest start) crc)
            digest))
     (declare (inline stuff-state))
     (let ((result (logxor #xffffffff (crc32-crc state))))
-      (etypecase digest
-        ((simple-array (unsigned-byte 8) (*))
-         (stuff-state result digest digest-start))
-        (null
-         (stuff-state result
-                      (make-array 4 :element-type '(unsigned-byte 8)) 0))))))
+      (stuff-state result digest digest-start))))
 
 (defdigest crc32 :digest-length 4 :block-length 1)
