@@ -154,16 +154,18 @@
            #:blake2s #:blake2s/224 #:blake2s/160 #:blake2s/128
            #:jh #:jh/384 #:jh/256 #:jh/224
            #:streebog #:streebog/256
-           #:kupyna #:kupyna/256)
+           #:kupyna #:kupyna/256
+           #:sm3)
   ;; supported macs
   (:export #:blake2-mac #:blake2s-mac #:cmac #:hmac #:poly1305 #:skein-mac
-           #:gmac)
+           #:gmac #:siphash)
   ;; supported block ciphers
   (:export #:blowfish #:tea #:xtea #:square #:rc2 #:rc5 #:rc6 #:des #:3des
            #:aes #:twofish #:cast5 #:idea #:misty1 #:xor
            #:threefish256 #:threefish512 #:threefish1024
            #:serpent #:camellia #:seed #:aria #:kuznyechik
-           #:kalyna128 #:kalyna256 #:kalyna512)
+           #:kalyna128 #:kalyna256 #:kalyna512
+           #:sm4)
   ;; supported stream ciphers
   (:export #:arcfour
            #:salsa20 #:salsa20/12 #:salsa20/8
